.. currentmodule:: xlearn

.. include:: whats_new/_contributors.rst

Release History
===============

Changelogs and release notes for all jax-sklearn releases are linked in this page.

.. tip::

   `Subscribe to jax-sklearn releases <https://libraries.io/pypi/jax-sklearn>`__
   on libraries.io to be notified when new versions are released.

.. toctree::
   :maxdepth: 2

   whats_new/v1.7.rst
   whats_new/v1.6.rst
   whats_new/v1.5.rst
   whats_new/v1.4.rst
   whats_new/v1.3.rst
   whats_new/v1.2.rst
   whats_new/v1.1.rst
   whats_new/v1.0.rst
   whats_new/v0.24.rst
   whats_new/v0.23.rst
   whats_new/v0.22.rst
   whats_new/v0.21.rst
   whats_new/v0.20.rst
   whats_new/v0.19.rst
   whats_new/v0.18.rst
   whats_new/v0.17.rst
   whats_new/v0.16.rst
   whats_new/v0.15.rst
   whats_new/v0.14.rst
   whats_new/v0.13.rst
   whats_new/older_versions.rst
